local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

local MUSICPLAYER_WIDTH = 200 				--width of the music player
local MUSICPLAYER_HEIGHT = 70				--height of the music player
local MUSICPLAYER_BUTTONMARGIN = 15	-- Left margin for the buttons' positions
local MUSICPLAYER_BUTTON_Y = -40			-- Y position of the buttons

-------------------------------------
-- Background Frame
-------------------------------------
GJB.mplayer.fbg = CreateFrame("Frame", "GJBP_BG", UIParent)
local fbg = GJB.mplayer.fbg
assert(fbg, "Failed to create frame " .. "GJBP_BG") -- failed to create the frame
fbg:SetPoint("CENTER", "UIParent", "CENTER", 0, 0)
fbg:SetMovable(true)
fbg:EnableMouse(true)
fbg:RegisterForDrag(unpack({"RightButton"}))

fbg:SetScript("OnDragStart", 
	function( self )
		if IsAltKeyDown() then
			self:StartMoving()
		end
	end
)
fbg:SetScript("OnDragStop", 
	function(self)
		self:StopMovingOrSizing()
		pos = GJB.db.profile.musicplayer.pos
		pos.a, pos.r, pos.rp, pos.x, pos.y = self:GetPoint(1)
	end
)

fbg:SetBackdrop(
{
	bgFile = "Interface/Tooltips/UI-Tooltip-Background",
	edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
	tile = true, tileSize = 16, edgeSize = 16,
	insets = { left = 4, right = 4, top = 4, bottom = 4 }
})
fbg:SetBackdropColor(0, 0, 0, 0.5)
fbg:SetBackdropBorderColor(1, 1, 0.5, 1)
fbg:SetWidth(MUSICPLAYER_WIDTH)
fbg:SetHeight(MUSICPLAYER_HEIGHT)
fbg:SetScale(1)
fbg:Show()

-------------------------------------
-- Header Frame
-------------------------------------
GJB.mplayer.fhdr = CreateFrame("Frame", "GJBP_Header", fbg)
local fhdr = GJB.mplayer.fhdr
assert(fhdr, "Failed to create frame " .. "GJBP_Header") -- failed to create the frame
fhdr.root = false
fhdr:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", 5, -1)
do
	local text = {}
	text = fhdr:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
	assert(text, "Error creating font string.")
	text:SetAllPoints(true)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("CENTER")
	text:SetTextColor(1, 1, 0.5, 1)
	text:SetText(L["GJBP_TITLE"])
end
fhdr:SetBackdropColor(123, 123, 123, 0)
fhdr:SetBackdropBorderColor(0, 0, 0, 0)
fhdr:SetWidth(190)
fhdr:SetHeight(20)
fhdr:SetScale(1)
fhdr:Show()

-------------------------------------
-- Title Frame
-------------------------------------
GJB.mplayer.ftitle = CreateFrame("Frame", "GJBP_Title", fbg)
local ftitle = GJB.mplayer.ftitle
assert(ftitle, "Failed to create frame " .. "GJBP_Title") -- failed to create the frame
ftitle.root = false
ftitle:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", 5, -17)
do
	local text = {}
	text = ftitle:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
	assert(text, "Error creating font string.")
	text:SetAllPoints(true)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("TOP")
	text:SetTextColor(1, 1, 1, 1)
	text:SetText("...")
	GJB.mplayer.ftitletext = text
end
ftitle:SetBackdropColor(123, 123, 123, 0)
ftitle:SetBackdropBorderColor(0, 0, 0, 0)
ftitle:SetWidth(190)
ftitle:SetHeight(20)
ftitle:SetScale(1)
ftitle:Show()

-------------------------------------
-- Back Button Frame
-------------------------------------
GJB.mplayer.fback = CreateFrame("Button", "GJBP_Back", fbg, UIPanelButtonTemplate)
local fback = GJB.mplayer.fback
assert(fback, "Failed to create frame " .. "GJBP_Back") -- failed to create the frame
fback.root = false
fback:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", MUSICPLAYER_BUTTONMARGIN, MUSICPLAYER_BUTTON_Y)
fback:SetBackdrop(
{
	bgFile = "Interface\\AddOns\\GarrisonJukeBox\\media\\back",
	edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
	tile = true, tileSize = 24, edgeSize = 1,
	insets = { left = 1, right = 1, top = 1, bottom = 1 }
})
fback:RegisterForClicks(unpack({"LeftButtonUp"}))

fback:SetScript("OnClick", 
	function(self, button, down)
		StopMusic()
		GJB.gMusicPlaying = false
		GJB.gMusicIndex	= GJB.gMusicIndex - 1
		if GJB.gMusicIndex < 1 then
			GJB.gMusicIndex = GJB.gMaxMusic
		end
		GJB:ProcessInfo()
	end
)
	
fback:SetScript("OnEnter",
	function(self)
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(L["CMD_PREV"])  -- This sets the top line of text, in gold.
		--GameTooltip:AddLine("Back", 1, 1, 1)
		GameTooltip:Show()
	end
)

fback:SetScript("OnLeave",
	function(self)
		GameTooltip:Hide()
	end
)

fback:SetHighlightTexture("Interface\\AddOns\\GarrisonJukeBox\\media\\btn-light", "ADD")
fback:SetBackdropColor(1, 1, 1, 1)
fback:SetBackdropBorderColor(0, 0, 0, 0)
fback:SetWidth(24)
fback:SetHeight(24)
fback:SetScale(1)
fback:Show()

-------------------------------------
-- Play Button Frame
-------------------------------------
GJB.mplayer.fplay = CreateFrame("Button", "GJBP_Play", fbg, UIPanelButtonTemplate)
local fplay = GJB.mplayer.fplay
assert(fplay, "Failed to create frame " .. "GJBP_Play") -- failed to create the frame
fplay.root = false
fplay:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", MUSICPLAYER_BUTTONMARGIN + 30, MUSICPLAYER_BUTTON_Y)
fplay:SetBackdrop(
{
	bgFile = "Interface\\AddOns\\GarrisonJukeBox\\media\\play",
	edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
	tile = true, tileSize = 24, edgeSize = 1,
	insets = { left = 1, right = 1, top = 1, bottom = 1 }
})
fplay:RegisterForClicks(unpack({"LeftButtonUp"}))

fplay:SetScript("OnClick", 
	function(self, button, down)
		StopMusic()
		GJB.gMusicPlaying = false
		GJB:ProcessInfo()
	end
)

fplay:SetScript("OnEnter",
	function(self)
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(L["CMD_PLAY"])  -- This sets the top line of text, in gold.
		--GameTooltip:AddLine("Back", 1, 1, 1)
		GameTooltip:Show()
	end
)

fplay:SetScript("OnLeave",
	function(self)
		GameTooltip:Hide()
	end
)

fplay:SetHighlightTexture("Interface\\AddOns\\GarrisonJukeBox\\media\\btn-light", "ADD")
fplay:SetBackdropColor(1, 1, 1, 1)
fplay:SetBackdropBorderColor(0, 0, 0, 0)
fplay:SetWidth(24)
fplay:SetHeight(24)
fplay:SetScale(1)
fplay:Show()

-------------------------------------
-- Stop Button Frame
-------------------------------------
GJB.mplayer.fstop = CreateFrame("Button", "GJBP_Stop", fbg, UIPanelButtonTemplate)
local fstop = GJB.mplayer.fstop
assert(fplay, "Failed to create frame " .. "GJBP_Stop") -- failed to create the frame
fstop.root = false
fstop:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", MUSICPLAYER_BUTTONMARGIN + 60, MUSICPLAYER_BUTTON_Y)
fstop:SetBackdrop(
{
	bgFile = "Interface\\AddOns\\GarrisonJukeBox\\media\\stop",
	edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
	tile = true, tileSize = 24, edgeSize = 1,
	insets = { left = 1, right = 1, top = 1, bottom = 1 }
})
fstop:RegisterForClicks(unpack({"LeftButtonUp"}))

fstop:SetScript("OnClick", 
	function(self, button, down)
		StopMusic()
		GJB:SetNowPlayingText("...")
		GJB.gMusicPlaying = false
		GJB:CancelTimer(self.musicTimer)
	end
)

fstop:SetScript("OnEnter",
	function(self)
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(L["CMD_STOP"])  -- This sets the top line of text, in gold.
		--GameTooltip:AddLine("Back", 1, 1, 1)
		GameTooltip:Show()
	end
)

fstop:SetScript("OnLeave",
	function(self)
		GameTooltip:Hide()
	end
)

fstop:SetHighlightTexture("Interface\\AddOns\\GarrisonJukeBox\\media\\btn-light", "ADD")
fstop:SetBackdropColor(1, 1, 1, 1)
fstop:SetBackdropBorderColor(0, 0, 0, 0)
fstop:SetWidth(24)
fstop:SetHeight(24)
fstop:SetScale(1)
fstop:Show()

-------------------------------------
-- Next Button Frame
-------------------------------------
GJB.mplayer.fnext = CreateFrame("Button", "GJBP_Next", fbg, UIPanelButtonTemplate)
local fnext = GJB.mplayer.fnext
assert(fnext, "Failed to create frame " .. "GJBP_Next") -- failed to create the frame
fnext.root = false
fnext:SetPoint("TOPLEFT", "GJBP_BG", "TOPLEFT", MUSICPLAYER_BUTTONMARGIN + 90, MUSICPLAYER_BUTTON_Y)
fnext:SetBackdrop(
{
	bgFile = "Interface\\AddOns\\GarrisonJukeBox\\media\\next",
	edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
	tile = true, tileSize = 24, edgeSize = 1,
	insets = { left = 1, right = 1, top = 1, bottom = 1 }
})
fnext:RegisterForClicks(unpack({"LeftButtonUp"}))

fnext:SetScript("OnClick", 
	function(self, button, down)
		StopMusic() 
		GJB.gMusicPlaying = false
		GJB:ProcessInfo()
	end
)

fnext:SetScript("OnEnter",
	function(self)
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(L["CMD_NEXT"])  -- This sets the top line of text, in gold.
		--GameTooltip:AddLine("Back", 1, 1, 1)
		GameTooltip:Show()
	end
)

fnext:SetScript("OnLeave",
	function(self)
		GameTooltip:Hide()
	end
)

fnext:SetHighlightTexture("Interface\\AddOns\\GarrisonJukeBox\\media\\btn-light", "ADD")
fnext:SetBackdropColor(1, 1, 1, 1)
fnext:SetBackdropBorderColor(0, 0, 0, 0)
fnext:SetWidth(24)
fnext:SetHeight(24)
fnext:SetScale(1)
fnext:Show()

--==============================================================

-------------------------------------
-- Function to show or hide the music player
-------------------------------------
function GJB:SetPlayerVisibility(visible)
	if visible then
		GJB.mplayer.fbg:Show()
	else
		GJB.mplayer.fbg:Hide()
	end
end

-------------------------------------
-- Function to set the text
-------------------------------------
function GJB:SetNowPlayingText(playing)
	local text = GJB.mplayer.ftitletext
	assert(text, "Error creating font string.")
	text:SetAllPoints(true)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("CENTER")
	text:SetTextColor(1, 1, 1, 1)
	text:SetText(playing)
end

-------------------------------------
-- Function to set the position of the player
-------------------------------------
function GJB:SetPlayerPos(pos)
	self.db.profile.musicplayer.pos = pos
	GJB.mplayer.fbg:ClearAllPoints()
	GJB.mplayer.fbg:SetPoint(pos.a, pos.r, pos.rp, pos.x, pos.y)
end

-------------------------------------
-- Function to update the player
-------------------------------------
function GJB:UpdateMusicPlayer()
	local pos = self.db.profile.musicplayer.pos
	self:SetPlayerPos( pos )
	self:SetPlayerVisibility( not self.db.profile.hidemusicplayer )
end
